@@ -2,17 +2,26 @@ from abc import ABC
 from sqlalchemy import update
 from pprint import pprint
 from sspo_db.model.core.models import ApplicationReference, Configuration
+from rabbitmqX.journal.journal import Journal
+from rabbitmqX.patterns.client.topic_client import Topic_Client
 
 class AbstractApplication(ABC):
 
     def __init__(self, service):
         self.service = service
 
+
     def get_all (self):
         return self.service.get_all()
         
     def create(self, object):
         self.service.create (object)
+        
+        pprint ("domain.sro."+object.is_instance_of)
+        self.topic_client = Topic_Client("domain.sro."+object.is_instance_of)
+        journal = Journal(str(object.uuid),object.is_instance_of,object.to_dict(),"create")
+        self.topic_client.send(journal)
+        pprint (object.to_dict())
 
     def ___retrive_by_external_id_and_seon_entity_name (self, external_id, seon_entity_name):
 
@@ -73,6 +82,11 @@ class AbstractApplication(ABC):
 
     def update (self, object):
         self.service.update(object)
+        pprint ("domain.sro."+object.is_instance_of)
+        self.topic_client = Topic_Client("domain.sro."+object.is_instance_of)
+        journal = Journal(str(object.uuid),object.is_instance_of,object.to_dict(),"update")
+        self.topic_client.send(journal)
+        pprint (object.to_dict())
     
     def retrive_by_name (self, name):
         return self.service.retrive_by_name(name)
