@@ -28,6 +28,11 @@ class Entity(Base, SerializerMixin):
 
     def to_dict(self):
         dict = super().to_dict()
-        dict['uuid'] = str(self.uuid)
+        dict['uuid'] = self.uuid_()
+        dict['level'] = "domain"
+        dict['ontology'] = "sro"
+        dict['is_instance_of'] = str(self.is_instance_of)
         return dict
-    
\ No newline at end of file
+    
+    def uuid_(self):
+        return str(self.uuid)
